==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-english.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","All Topics");
define("_NOCOMMENTS","No Comments");
define("_UCOMMENT","Comment");
define("_REVIEWS","Reviews");
define("_SEARCHUSERS","Search in User's Database");
define("_SEARCHSECTIONS","Search in Special Sections");
define("_SEARCHREVIEWS","Search in Reviews");
define("_SEARCHIN","Search in");
define("_ARTICLES","Articles");
define("_ALLAUTHORS","All Authors");
define("_ALL","All");
define("_WEEK","week");
define("_WEEKS","weeks");
define("_MONTH","month");
define("_MONTHS","months");
define("_SEARCHON","Search on:");
define("_SSTORIES","Stories");
define("_SSECTIONS","Sections");
define("_SUSERS","Users");
define("_NOMATCHES","No matches found to your query");
define("_PREVMATCHES","previous matches");
define("_NEXTMATCHES","next matches");
define("_INSECTION","Article in the Section");
define("_NONAME","No name entered");
define("_SCOMMENTS","Comments");
define("_SEARCHRESULTS","Search Results");
define("_CONTRIBUTEDBY","Contributed by");
define("_UCOMMENTS","Comments");
define("_MATCHTITLE","Match on Title");
define("_MATCHTEXT","Match on Article's text");
define("_MATCHBOTH","Match on Title and Article's text");
define("_SREPLY","Reply");
define("_SREPLIES","Replies");
define("_ATTACHART","Attached to Article");
define("_PAGES","Pages");
define("_REVIEWSCORE","Score for this Review");
define("_PAGE","Page");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-english.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","All Topics");
define("_NOCOMMENTS","No Comments");
define("_UCOMMENT","Comment");
define("_REVIEWS","Reviews");
define("_SEARCHUSERS","Search in User's Database");
define("_SEARCHSECTIONS","Search in Special Sections");
define("_SEARCHREVIEWS","Search in Reviews");
define("_SEARCHIN","Search in");
define("_ARTICLES","Articles");
define("_ALLAUTHORS","All Authors");
define("_ALL","All");
define("_WEEK","week");
define("_WEEKS","weeks");
define("_MONTH","month");
define("_MONTHS","months");
define("_SEARCHON","Search on:");
define("_SSTORIES","Stories");
define("_SSECTIONS","Sections");
define("_SUSERS","Users");
define("_NOMATCHES","No matches found to your query");
define("_PREVMATCHES","previous matches");
define("_NEXTMATCHES","next matches");
define("_INSECTION","Article in the Section");
define("_NONAME","No name entered");
define("_SCOMMENTS","Comments");
define("_SEARCHRESULTS","Search Results");
define("_CONTRIBUTEDBY","Contributed by");
define("_UCOMMENTS","Comments");
define("_MATCHTITLE","Match on Title");
define("_MATCHTEXT","Match on Article's text");
define("_MATCHBOTH","Match on Title and Article's text");
define("_SREPLY","Reply");
define("_SREPLIES","Replies");
define("_ATTACHART","Attached to Article");
define("_PAGES","Pages");
define("_REVIEWSCORE","Score for this Review");
define("_PAGE","Page");

?>
